@@ -79,47 +79,50 @@ class MachineSet(NamespacedResource):
         self.provider_spec = provider_spec or {}
 
     def to_dict(self):
-        super().to_dict()
-        if not self.yaml_file:
-            _spec, _metadata, _labels = ("spec", "metadata", "labels")
-            (
-                _cluster_api_cluster,
-                _cluster_api_machine_role,
-                _cluster_api_machine_type,
-                _cluster_api_machineset,
-            ) = (
-                "cluster-api-cluster",
-                "cluster-api-machine-role",
-                "cluster-api-machine-type",
-                "cluster-api-machineset",
-            )
+        res = super().to_dict()
+        if self.yaml_file:
+            return res
 
-            self.res[_metadata][_labels] = {
-                f"{self.api_group}/{_cluster_api_cluster}": self.cluster_name,
-                f"{self.api_group}/{_cluster_api_machine_role}": self.machine_role,
-                f"{self.api_group}/{_cluster_api_machine_type}": self.machine_type,
-            }
+        _spec, _metadata, _labels = ("spec", "metadata", "labels")
+        (
+            _cluster_api_cluster,
+            _cluster_api_machine_role,
+            _cluster_api_machine_type,
+            _cluster_api_machineset,
+        ) = (
+            "cluster-api-cluster",
+            "cluster-api-machine-role",
+            "cluster-api-machine-type",
+            "cluster-api-machineset",
+        )
 
-            self.res[_spec] = {
-                "replicas": self.replicas,
-                "selector": {
-                    "matchLabels": {
+        res[_metadata][_labels] = {
+            f"{self.api_group}/{_cluster_api_cluster}": self.cluster_name,
+            f"{self.api_group}/{_cluster_api_machine_role}": self.machine_role,
+            f"{self.api_group}/{_cluster_api_machine_type}": self.machine_type,
+        }
+
+        res[_spec] = {
+            "replicas": self.replicas,
+            "selector": {
+                "matchLabels": {
+                    f"{self.api_group}/{_cluster_api_cluster}": self.cluster_name,
+                    f"{self.api_group}/{_cluster_api_machineset}": f"{self.cluster_name}-{self.machine_role}",
+                }
+            },
+            "template": {
+                _metadata: {
+                    _labels: {
                         f"{self.api_group}/{_cluster_api_cluster}": self.cluster_name,
+                        f"{self.api_group}/{_cluster_api_machine_role}": self.machine_role,
+                        f"{self.api_group}/{_cluster_api_machine_type}": self.machine_type,
                         f"{self.api_group}/{_cluster_api_machineset}": f"{self.cluster_name}-{self.machine_role}",
                     }
                 },
-                "template": {
-                    _metadata: {
-                        _labels: {
-                            f"{self.api_group}/{_cluster_api_cluster}": self.cluster_name,
-                            f"{self.api_group}/{_cluster_api_machine_role}": self.machine_role,
-                            f"{self.api_group}/{_cluster_api_machine_type}": self.machine_type,
-                            f"{self.api_group}/{_cluster_api_machineset}": f"{self.cluster_name}-{self.machine_role}",
-                        }
-                    },
-                    _spec: {"providerSpec": self.provider_spec},
-                },
-            }
+                _spec: {"providerSpec": self.provider_spec},
+            },
+        }
+        return res
 
     @property
     def available_replicas(self):
@@ -177,13 +180,13 @@ class MachineSet(NamespacedResource):
         Returns:
             bool: True if scaling the machine-set was successful or wait=False, False otherwise.
         """
-        super().to_dict()
-        self.res.update({"spec": {"replicas": replicas}})
+        body = super().to_dict()
+        body.update({"spec": {"replicas": replicas}})
 
         self.logger.info(
             f"Scale machine-set from {self.desired_replicas} replicas to {replicas} replicas"
         )
-        self.update(resource_dict=self.res)
+        self.update(resource_dict=body)
         if wait:
             return self.wait_for_replicas(timeout=wait_timeout, sleep=sleep)
         return True
